Change Log
**********

These are the enhancements, breaking changes and bug fixes of note between each
release.

.. _v0.1.0:

`0.1.0`_ - 2022-01-15
=====================

.. _0.1.0: https://gitlab.com/signalytics/signalyzer/compare

* First release.
